<?php

	/*
	* Plugin Name: Import Shipment Tracking Details via XML
	* Plugin URI: https://www.pluginhive.com/product/woocommerce-shipment-tracking-pro/
	* Description: This plugin allows you to import shipment tracking details via a XML file using PluginHive's WooCommerce Shipment Tracking Pro
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.0.0
	* Text Domain: ph_shipment_tracking_import_xml_file
	* Copyright: 2020 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 4.2.2
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	function ph_import_xml_file_required_plugins()
	{

		$ph_addon_required_plugins 	= false;

		$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

		// Multisite case
		if ( is_multisite() ) {
			$active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
		}

		if ( in_array( 'ph-woocommerce-shipment-tracking/woocommerce-shipment-tracking.php', $active_plugins ) ) {

			$ph_addon_required_plugins = true;
		}

		return $ph_addon_required_plugins;
	}

	// Auto Deactivate
	add_action( 'admin_init', 'ph_shipment_tracking_import_xml_file_deactivate' );

	if ( ! function_exists( 'ph_shipment_tracking_import_xml_file_deactivate' ) ) {
		function ph_shipment_tracking_import_xml_file_deactivate() {

			$ph_required_plugins 	= ph_import_xml_file_required_plugins();

			if ( !$ph_required_plugins ) {

				deactivate_plugins( plugin_basename( __FILE__ ) );
				wp_safe_redirect( admin_url('plugins.php') );
			}
		}
	}

	function ph_import_xml_file_activation_check(){

		$ph_required_plugins 	= ph_import_xml_file_required_plugins();

		if ( !$ph_required_plugins ) {

			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Custom Estimated Delivery Date Format without activating Estimated Delivery Plugin. Kindly activate <b>Estimated Delivery Plugin</b> and then try again", "ph_shipment_tracking_import_xml_file" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_import_xml_file_activation_check' );

	if( !class_exists('PH_Shipment_Tracking_Import_XML_File') ) {

		class PH_Shipment_Tracking_Import_XML_File {

			public function __construct() {

				$this->id		= 'ph_shipment_tracking_import_xml_file';

				add_filter( 'ph_shipment_trackig_support_xml_import', array( $this, 'ph_shipment_tracking_support_xml_file_import'), 12, 2);
				add_filter( 'ph_shipment_tracking_modify_file_content', array( $this, 'ph_shipment_tracking_convert_xml_to_csv'), 12, 2);
			}

			// To support XML files while getting it from FTP?SFTP
			function ph_shipment_tracking_support_xml_file_import( $xml_support ) {

				$xml_support = true;

				return $xml_support;
			}

			// To get the XML data and return the CSV File
			function ph_shipment_tracking_convert_xml_to_csv( $file ) {

				$xmlData = file_get_contents($file);

				$xmlString 		= simplexml_load_string( $xmlData ); 
				$xmlJson 		= json_encode( $xmlString );  
				$xmlArray 		= json_decode( $xmlJson, true ); 

				$orderNumber 	= isset($xmlArray['TelegramHeader']) && isset($xmlArray['TelegramHeader']['OrderNumber']) ? $xmlArray['TelegramHeader']['OrderNumber'] : '';	
				$createDate 	= isset($xmlArray['SalesOrderHeader']) && isset($xmlArray['SalesOrderHeader']['Shipping']) ? $xmlArray['SalesOrderHeader']['Shipping']['Date'] : '';	
				$carrierCode 	= isset($xmlArray['SalesOrderHeader']) && isset($xmlArray['SalesOrderHeader']['Shipping']) ? $xmlArray['SalesOrderHeader']['Shipping']['ProductCode'] : '';	
				$trackingDesc 	= '';
				$orderStatus 	= 'completed';

				// Convert Date Format to WordPress Format
				$wp_date_format = get_option('date_format');

				if( !empty($createDate) ) {

					$trackingDate 	= date( $wp_date_format, strtotime($createDate) );
				} else {

					$trackingDate 	= date( $wp_date_format );
				}

				// Carrier Code Array
				$carrierCodeArray = array(
					'31202' 	=> 'gls',
					'31203' 	=> 'gls',
					'31206' 	=> 'gls',
					'31207' 	=> 'dhl-express',
					'31208' 	=> 'dhl-express',
				);

				$carrierName 	= !empty($carrierCode) && array_key_exists($carrierCode, $carrierCodeArray) ? $carrierCodeArray[$carrierCode] : '';

				// Get Tracking Numbers
				$orderLineItems 	= isset($xmlArray['SalesOrderLine']) ? $xmlArray['SalesOrderLine'] : array();
				$trackingNumArray 	= array();
				$trackingNumbers 	= '';

				if( !empty($orderLineItems) && is_array($orderLineItems) ) {

					foreach ( $orderLineItems as $key => $lineItems ) {

						if( isset($lineItems['TrackingNumber']) ) {

							$trackingNumArray[] = $lineItems['TrackingNumber'];
							
						} else if( $key == 'TrackingNumber' ) {

							$trackingNumArray[] = $orderLineItems[$key];
						}
					}
				}

				// Get the Unique Tracking Numbers and create strings
				if( !empty($trackingNumArray) ) {
					
					$trackingNumArray 	= array_unique($trackingNumArray);
					$trackingNumbers 	= implode(',', $trackingNumArray);
				}

				if( !empty($orderNumber) && !empty($carrierName) && !empty($trackingNumbers) ) {

					// Create a temparory CSV file
					$tempFile 	= ABSPATH.'wp-content/uploads/ph-shipment-tracking-xml-to-temp-csv.csv';

					$list = array (

						array(
							'ID',
							'Carrier',
							'TrackingNumber',
							'ShippingDate',
							'Description',
							'OrderStatus'
						),

						array(
							$orderNumber,
							$carrierName,
							$trackingNumbers,
							$trackingDate,
							$trackingDesc,
							$orderStatus,
						),
					);

					// Open CSV file
					$tempCSV = fopen( $tempFile, "w" );

					// Write CSV Data in to the file
					foreach ($list as $line) {

						fputcsv( $tempCSV, $line, ';' );
					}

					fclose($tempCSV);

					// Return new CSV File Path
					return $tempFile;

				}
				
				return $file;
				
			}
			
		}
	}

	new PH_Shipment_Tracking_Import_XML_File();